==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fLdc2.h <==
// class soot.coffi.Instruction_Ldc2

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 5d2ea0832212d866 soot_coffi_Instruction__5fLdc2
// @dep_class d13384827121be19 soot_coffi_Instruction__5fintindex

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintindex

#include "soot/coffi/Instruction__5fintindex.h"

#ifndef _JC_soot_coffi_Instruction__5fLdc2_H_
#define _JC_soot_coffi_Instruction__5fLdc2_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fLdc2$sub_refs	_jc_soot_coffi_Instruction__5fLdc2$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fLdc2$sub_nonrefs	_jc_soot_coffi_Instruction__5fLdc2$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLdc2$refs	_jc_soot_coffi_Instruction__5fLdc2$refs;
typedef struct _jc_soot_coffi_Instruction__5fLdc2$nonrefs	_jc_soot_coffi_Instruction__5fLdc2$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLdc2$object	_jc_soot_coffi_Instruction__5fLdc2$object;

typedef const struct _jc_soot_coffi_Instruction__5fLdc2$vmethods	_jc_soot_coffi_Instruction__5fLdc2$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fLdc2$vtable	_jc_soot_coffi_Instruction__5fLdc2$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fLdc2$vtype	_jc_soot_coffi_Instruction__5fLdc2$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fLdc2$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fLdc2$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fLdc2$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fLdc2$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintindex$vmethods	soot_coffi_Instruction__5fintindex;
	_jc_soot_coffi_Instruction__5fLdc2$vmethods	soot_coffi_Instruction__5fLdc2;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fLdc2$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fLdc2$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLdc2$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLdc2$refs {
    _jc_soot_coffi_Instruction__5fLdc2$sub_refs	soot_coffi_Instruction__5fLdc2;
    _jc_soot_coffi_Instruction__5fintindex$sub_refs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLdc2$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLdc2$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction__5fLdc2$sub_nonrefs	soot_coffi_Instruction__5fLdc2;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fLdc2$object {
	_jc_soot_coffi_Instruction__5fLdc2$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fLdc2$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fLdc2$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fLdc2$vtype _jc_soot_coffi_Instruction__5fLdc2$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fLdc2, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fLdc2$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fLdc2_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fLdc2.h <==
// class soot.coffi.Instruction_Ldc2

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 5d2ea0832212d866 soot_coffi_Instruction__5fLdc2
// @dep_class d13384827121be19 soot_coffi_Instruction__5fintindex

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintindex

#include "soot/coffi/Instruction__5fintindex.h"

#ifndef _JC_soot_coffi_Instruction__5fLdc2_H_
#define _JC_soot_coffi_Instruction__5fLdc2_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fLdc2$sub_refs	_jc_soot_coffi_Instruction__5fLdc2$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fLdc2$sub_nonrefs	_jc_soot_coffi_Instruction__5fLdc2$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLdc2$refs	_jc_soot_coffi_Instruction__5fLdc2$refs;
typedef struct _jc_soot_coffi_Instruction__5fLdc2$nonrefs	_jc_soot_coffi_Instruction__5fLdc2$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLdc2$object	_jc_soot_coffi_Instruction__5fLdc2$object;

typedef const struct _jc_soot_coffi_Instruction__5fLdc2$vmethods	_jc_soot_coffi_Instruction__5fLdc2$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fLdc2$vtable	_jc_soot_coffi_Instruction__5fLdc2$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fLdc2$vtype	_jc_soot_coffi_Instruction__5fLdc2$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fLdc2$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fLdc2$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fLdc2$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fLdc2$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintindex$vmethods	soot_coffi_Instruction__5fintindex;
	_jc_soot_coffi_Instruction__5fLdc2$vmethods	soot_coffi_Instruction__5fLdc2;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fLdc2$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fLdc2$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLdc2$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLdc2$refs {
    _jc_soot_coffi_Instruction__5fLdc2$sub_refs	soot_coffi_Instruction__5fLdc2;
    _jc_soot_coffi_Instruction__5fintindex$sub_refs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLdc2$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLdc2$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction__5fLdc2$sub_nonrefs	soot_coffi_Instruction__5fLdc2;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fLdc2$object {
	_jc_soot_coffi_Instruction__5fLdc2$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fLdc2$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fLdc2$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fLdc2$vtype _jc_soot_coffi_Instruction__5fLdc2$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fLdc2, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fLdc2$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fLdc2_H_ */
